######################################################################
#:CQCC::MsgCat_English
#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2001, 2008. All Rights Reserved.
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#

=head1 NAME

CQCC::MsgCat_English - Message catalog for CQCC integration

=head1 CLASS DESCRIPTION

This class is subclass of CQCC::MsgCat which provides all the user
visible messages needed by the standard CQCC integration in the form
of message catalog entries. These will be used by called to the
IOPrompt(), IOMessage(), and IOListSelect methods to present user 
dialogs, messages, and menus.

In order to be used, the configuration file can ask for this 
class (default) or an alternate translation as shown below:

    &SetConfigParm("MsgCatInterface", "CQCC::MsgCat_English");

Message prefixes indicate the class that uses the message and its
type: 

    CC (CCase)
    CQ (CQuest), CQP (CQPerlAPI), CQS (CQSchema), CQW (CQWeb)
    IO (IOBase), IOC (IOClearPrompt)
    PM (Parm)
    TBASE (TriggerBase), TCQCC (TriggerCQCC), TTEST (TriggerTest)

Types: E(rror), I(nfo), M(enu), P(rompt) 

Translations of this catalog should be done by following these steps:

1) Make a copy of this file, naming it MsgCat_<language>.pm where
   <language> is the name of the target language. 

2) Inside the copy, replace all instances of MsgCat_English with 
   MsgCat_<language>. 

3) Translate the yes and no strings in the Initialize function. 
   These strings are embedded into the AddMsg calls later.

   Remove the YesNo method at the bottom of this file so that 
   YesNo matching is done using the base class method in MsgCat.pm

4) In the copy, edit each &AddMsg call to change only the third
   parameter. The %s markers indicate where the arguments (second
   paramater list) will be placed. Do not change the order of these.
   Do NOT add double-quotes (") within the body of the messages. 

   Note: Some messages are information about the config.pl parameters
   and are not yet used in the integration. These are less important.
   See the config.pl file for more information. 

5) Test the translation printout as follows: 

   Look for syntactic errors: 

      cqperl -cw -I.. MsgCat_<language>.pm 
    
   Review the output of the messages with arguments placeholders.

      cqcc_launch CQCC/config.pl -op classtest 
         CQCC::MsgCat_<language>

5) Modify the config file (CQCC/config.pl) to use the new
   translation: 

   &SetConfigParm("MessageCatalogInterface", 
       "CQCC::MsgCat_<language>");

   Use local environment variables if desired to set the message 
   catalog. 

SUPPORT POLICY: See TriggerCQCC.pm for the Rational Support Policy. 

=head1 METHODS

=cut

######################################################################
#::Package declarations
######################################################################

package CQCC::MsgCat_English;
use CQCC::MsgCat;
@ISA = qw( CQCC::MsgCat );

use strict;
use CQCC::Parm;
sub Version { return '2.2' };

######################################################################
#::Class Globals 
######################################################################

my %arguments;      # Temp hash list for argument list during build
my %catalog;        # and message catalog

my $yes_string;     # Set during initialization from MsgCat vars
my $no_string; 

######################################################################
#::method Classtest

=over 6

=item C<ClassTest(@args)>

This function creates a message catalog instance by calling
IOClassFactory(), calls the super classes SelfTest() method, 
then runs additional tests specific to this set of messages to
ensure we are able to look up messages and handle error conditions
properly. 

=back

=cut

#################################################################

sub ClassTest { 
    my @args = @_;
    my $msgcat = new CQCC::MsgCat_English();

    $msgcat->SelfTest(@args);

    print "########################################\n";
    print "Test the message method with variety of cases\n";
    print "\n------\nShould complain about unknown msg key\n\n";
    print $msgcat->Message( [ "USAGE" ] );

    print "\n------\nShould show substitution for missing args\n\n";
    print $msgcat->Message( [ "TBASE_I_USAGE", "cqcc_trigger" ] );

    print "\n------\n", 
          "Should print correctly with cqcc_trigger as command\n\n";
    print $msgcat->Message( [ "TBASE_I_USAGE", "cqcc_trigger",
                            "cqcc_trigger", "cqcc_trigger" ]);

    print "\n------\nShould print out pathname at beginning\n\n";
    print $msgcat->Message( [ "CC_E_VOLIST", "<pathname>" ]) . "\n";
    return 0;
} 

#################################################################
#::method Initialize

=over 6

=item C<Initialize()>

This method is used to load the message catalog with tagged entries
and their arguments. Each message uses AddMsg() to add the msg tag
value, arglist and catalog entries to local hashlists that will be
stored into the object after the initialization is complete by the new
method.

=back

=cut

######################################################################

sub Initialize { 
    my $self = shift;
 
#################################################################
#:::CC_*:    CCase class messages

##################################################

#::::CC_E:  Error messages

    &AddMsg("CC_E_NO_HLINK", [ "<ERRMSG>" ],
"Clearcase can't make a hyperlink to the new associations:
%s");

    #----------------------------------------
    &AddMsg("CC_E_VOLIST",   [ "<PATHNAME>" ],
"Clearcase cannot obtain a unique identification for %s.  
Cannot make or update associations.  To recover, try to cancel 
checkout of the file (saving your changes with the keep or save option); 
check the file out again; restore your changes; and check the file in again.");

    #----------------------------------------
    &AddMsg("CC_E_CONFIG_SPEC_CONFLICT",   [ ],
"Current config spec is not selecting the checked out element. This config 
spec is not supported when your site uses only pre-checkin triggers.
Either change your config spec to select the checked-out element or 
ask your administrator to enable PostCheckin Commit triggers");

#################################################################
#:::CQ_*:    CQuest class messages

##################################################

#::::CQ_E:  Error messages

    &AddMsg("CQ_E_ASSOC_NOT_ALLOWED", 
             [ "<BAD_IDS>", "<RESTRICTIONS>" ],
"The following associations are not acceptable:

%s

They do not meet local restrictions: 

%s");

    #----------------------------------------
    &AddMsg("CQ_E_LOGIN_FAILED", [ "<DATABASE>" ],
"Failed to login to ClearQuest database %s with saved
user name and password, which may mean you are using the 
wrong database repository or the wrong logon name and password. 
Do you wish to re-enter logon name and password ?");

    #----------------------------------------
    &AddMsg("CQ_E_MIXED_ENTITIES", [ "<RECTYPE_DB_LIST>" ],
"This integration does not currently support a mixture of 
different database and record types used in the same association list.

%s");

    #----------------------------------------
    &AddMsg("CQ_E_NO_VALID_SCHEMA",  ["<DATABASE>", "<RECORD TYPE>"],
"Validate Database/Entity: No schema found in config file for 
     %s : %s");

    #----------------------------------------
    &AddMsg("CQ_E_OP_UNSUPPORTED", [ "<CLASS>", "<OP>" ],
"Clearquest %s does not support the following operation: %s");

    #----------------------------------------
    &AddMsg("CQ_E_TEST_LOGIN_FAILED", [ ],
"Failed to login to ClearQuest database with test 
user name and password");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_DATABASE",  ["<DBNAME>"],
"ClearQuest unable to switch to using database %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_ENTITY", ["<RECORD TYPE>"],
"ClearQuest Query failed, unknown record type: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_QUERY",  ["<QUERY>"],
"ClearQuest Query failed, unknown or empty query: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_RESULTS", ["<RESULTS>"],
"ClearQuest Query failed, unknown or empty results set: %s");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_REPLICA_NAME", [],
"Multisite support is enabled but the database replica name
cannot be determined from the database; the CQCC_REPLICA_NAME 
configuration parameter is not set to provide a default value. 
Please contact your administrator.");

    #----------------------------------------
    &AddMsg("CQ_E_UNKNOWN_SCHEMA",  ["<RECORD TYPE>"],
"ClearQuest Query failed, no schema known for record type %s");

##################################################
#::::CQ_P:  Prompt messages

    &AddMsg("CQ_P_LOGIN", [],
"Enter the username and password for the ClearQuest database, 
separated by a space:");

    &AddMsg("CQ_P_LOGIN_DIALOG", ["<DATABASE>"],
"Login to ClearQuest database %s");

    &AddMsg("CQ_P_LOGIN_USER", ["<DATABASE>"],
"Login to ClearQuest database %s
Enter User Name");

    &AddMsg("CQ_P_LOGIN_PASSWORD", ["<MASK_FLAG>"],
"Login to ClearQuest
Enter Password%s");

    #----------------------------------------
    &AddMsg("CQ_P_LOGIN_CLEAR", [ ],
"Do you want to clear ClearQuest login information and relogin?");

#################################################################
#:::CQP_*:   CQPerlAPI class messages

##################################################
#::::CQPerlAPI Parameter descriptions

    &AddMsg("CQCC_WEB_DATABASE_SET", [], 
"Similar to CQCC_DATABASE_SET but only used by the CQWeb interface.
May or may not be set to the same value. No default value.");

##################################################
#::::CQP_E:  Error messages

    &AddMsg("CQP_E_ERRCHECK",      [ "<CALLER>", "<ERRMSG>" ],
"ClearQuest Perl API reported an error in %s: 
%s");

    #----------------------------------------
    &AddMsg("CQP_E_CODE_PAGE_MISMATCH", [],
"ClearQuest data code page does not match your client code page.
Unable to display information from database or make changes.");

    #----------------------------------------
    &AddMsg("CQP_E_UNKNOWN_DB", [ "<DATABASE>", "<DB_LIST>" ],
"Desired database %s was not found in the current database
repository.  Only the following databases were found: 
%s");

    #----------------------------------------
    &AddMsg("CQP_E_QUERY_INVALID", [ "<QUERY_NAME>", "<OPERATOR>" ],
"The current ClearQuest query defined in the site configuration file
is invalid because of an unknown operation %s. The unknown operation is 
located in %s");

    #----------------------------------------
    &AddMsg("CQP_E_WRONG_ENTITY", ["<RIGHT TYPE>", "<WRONG TYPE>"],
"ClearQuest Query invalid - query expected to return record
type %s. However, the query returns %s instead. Please select a different query.");

#################################################################
#:::CQS_*:   CQSchema class messages

##################################################

#::::CQS_E:  Error messages

    &AddMsg("CQS_E_UNKNOWN_KEY",   [ "<KEY>", "<SCHEMA>" ],
"DefineCQSchema - unknown key (%s) has been found. Problem occurs in schema
(%s), defined in the site configuration file");

    #----------------------------------------
    &AddMsg("CQS_E_UNKNOWN_QUERY", [ "<QUERY>", "<SCHEMA>" ],
"DefineCQSchema - unknown restrictions query (%s) has been found. Problem occurs for schema
(%s), defined in the site configuration file
");

    #----------------------------------------
    &AddMsg("CQS_E_CONVERSION_ERROR", [ "<FIELD>","<ERROR>"],
"Conversion error for CQSchema information field %s:
%s");

#################################################################
#:::CQW_*:   CQWeb class messages

##################################################

#::::CQW_E:  Error messages

    &AddMsg("CQW_E_DATABASE_INVALID", [ "<ERRMSG>" ],
"The Clearquest database name is invalid. This message usually
indicates that the username or password was passed incorrectly.
%s");

    #----------------------------------------
    &AddMsg("CQW_E_INVALID_SERVER", [],
"There isn't enough information to connect to the ClearQuest Web 
server. You need to set environment or configuration variables 
to specify the server (CQCC_SERVER) and web page (CQCC_SERVERROOT)
OR the entire URL (CQCC_URL) to access the web server. The current
operation will be canceled. 
");

    #----------------------------------------
    &AddMsg("CQW_E_OP_FAILED", [ "<WARNING>", "<ERRMSG>" ],
"Clearquest web server reported an error in the current operation.
%s

%s");

    #----------------------------------------
    &AddMsg("CQW_E_POSTCOMMAND", ["<URL>"],
"There was no result returned by the ClearQuest Web server connection
after sending a message. Please use a web browser to connect to 
%s
to make sure that you have a working server URL address.
If you receive a message about XML processing problems that indicates
a successful connection.");

################################################################
#:::CQWJ_*:   CQWebJava class messages

##################################################
#::::CQWJ_E:  Error messages

    #----------------------------------------
    &AddMsg("CQWJ_E_DATABASE_INVALID", [ "<ERRMSG>" ],
"The ClearQuest Web database name is invalid. This message usually
indicates that the username or password was passed incorrectly.
%s");

    #----------------------------------------
    &AddMsg("CQWJ_E_DATABASE_SET_UNSET", [ "<PARM>" ],
"The %s parameter must be set for ClearQuest Web to provide 
a default database set to use.");

    #----------------------------------------
    &AddMsg("CQWJ_E_INVALID_SERVER", [],
"There isn't enough information to connect to the ClearQuest Web 
server. You need to set environment or configuration variables 
to specify the server (CQCC_SERVER) and web page (CQCC_SERVERROOT).
The current operation will be canceled. 
");

    #----------------------------------------
    &AddMsg("CQWJ_E_OP_FAILED", [ "<WARNING>", "<ERRMSG>" ],
"ClearQuest Web server reported an error in the current operation.
%s

%s");

    #----------------------------------------
    &AddMsg("CQWJ_E_QUERY_ORDER", [ "<NAMES>" ],
"ClearQuest Web queries must include the 'dbid' field first or not at 
all (%s)");

    #----------------------------------------
    &AddMsg("CQWJ_E_POSTCOMMAND", ["<URL>"],
"There was no result returned by the ClearQuest Web server connection
after sending a message. Please use a web browser to connect to 
%s
to make sure that you have a working server URL address.
");

    #----------------------------------------
    &AddMsg("CQWJ_E_CONVERSION_ERROR", [ "<FIELD>","<ERROR>"],
"Conversion error for CQWebJava field \'%s\':
%s");

################################################################
#:::CQWJP_*:   CQWebJavaParser class messages

##################################################

#::::CQWJP_E:  Error messages

    &AddMsg("CQWJP_E_XML_ERROR", [ "<Message>" ],
"CQWebJava XML Parsing error: %s\n");

    &AddMsg("CQWJP_E_UNEXPECTED_ELEMENT", [ "<ElementName>" ],
"CQWebJava XML Parser processElement found unexpected element: %s\n");

################################################################
#:::IO_*:    IOBase class messages

##################################################
#::::IO_E:  Error messages

    &AddMsg("IO_E_ANSWER_RANGE", [ "<ANSWER>" ],
"Answer (%s) is outside expected range
Choose a number between (1) and (N), then hit RETURN");

    #----------------------------------------
    &AddMsg("IO_E_CCRC_REQTS", [], 
"Running the Base CC/CQ integration in a CCRC web environment 
requires satisfying the following conditions:

(1) CQCC_CACHE_ROOT must be set in the config file to provide a 
   central directory in which the integration can cache individual 
   user parameter information between trigger calls. 

(2) The CCRC Server must be running ClearCase 7.0.1 or later.
");

    #----------------------------------------
    &AddMsg("IO_E_FACTORY_FAILED",
        [ "<CLASSINTERFACE>", "<CLASSNAME>" ],
"Application unable to make an instance of class 
%s (%s)");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_MKDIR", ["<DIR>", "<ERR>"],
"Unable to create directory %s
%s");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_FILE_OP", ["<OPERATION>", "<FILE1>", "<FILE2>", "<CALLER>"],
"IOFileOperation: operation %s failed 
using %s 
and %s
caller was %s");

    #----------------------------------------
    &AddMsg("IO_E_FAILED_FILE_LOCK", ["<MODE>", "<FILE>"],
"Unable to get file lock (%s) on %s");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_ATRIA_DIR", [],
"Unable to determine Clearcase home directory.
Please modify PATH variable to include where to find Clearcase.");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_FILE_OP", ["<OPERATION>", "<FILE1>", "<FILE2>", "<CALLER>"],
"Unknown file operation %s 
using %s 
and %s
caller was %s");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_FILE_OUTPUT", ["<OPERATION>", "<FILE>"],
"Unknown file output mode %s 
using %s");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_ROOT_DIR", [ "<BASEDIR>" ],
"Unable to create new subdirectories since the base directory 
%s doesn't exist.");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_SERIES_KEY", [],
"Unable to determine either CLEARCASE_SERIES_ID or CLEARCASE_PPID for unique key");

    #----------------------------------------
    &AddMsg("IO_E_INVALID_TEMP_DIR", [],
"Unable to determine temporary directory for integration to use. 
Please set TMPDIR or TMP or TEMP environment varible.");

    #----------------------------------------
    &AddMsg("IO_E_MSGTAG_UNDEF", [],
"IOMessage dialog routine got an undefined message tag");

    #----------------------------------------
    &AddMsg("IO_E_SINGLE_ANSWER", [],
"Please enter a single value only");

    #----------------------------------------
    &AddMsg("IO_E_MSGCAT_NOT_INITIALIZED", [],
"IOConvertString: message catalog not initialized");

    &AddMsg("IO_E_OEM_ACP_MISMATCH", [ "<CODEPAGE>","<OEM_CODEPAGE>","<CODEPAGE_NUM>"],
"The local codepage (%s) is different than the codepage being
used by standard output (%s) which may cause display problems.
Use 'chcp %s' in the command prompt window to correct this.");

    #----------------------------------------
    &AddMsg("IO_E_NO_STDIN", [],
"Attempt is being made to prompt the user but running in non-interactive
environment, unable to continue.");

##################################################
#::::IO_P:  Prompt messages

    &AddMsg("IO_P_LISTSELECT", ["<SUFFIX>" ], "\nEnter choice%s: ");

    #----------------------------------------
    &AddMsg("IO_P_MESSAGE", [], "Proceed (y/n) ? ");

    #----------------------------------------
    &AddMsg("IO_P_PROMPT", [], " ");

    #----------------------------------------
    &AddMsg("IO_P_YES", [], "Yes");

    #----------------------------------------
    &AddMsg("IO_P_NO", [], "No");

    #----------------------------------------
    &AddMsg("IO_P_YES_NO", [], "(y/n)");

    #----------------------------------------
    &AddMsg("IO_P_USERNAME", [], "User Name");

    #----------------------------------------
    &AddMsg("IO_P_PASSWORD", [], "Password");

    #----------------------------------------
    &AddMsg("IO_P_AUTOBREAK_WAIT", [], 
"Waiting for another process to complete working with a shared 
resource before proceeding, please wait a little longer");

    #----------------------------------------
    &AddMsg("INFO", [], "INFO");

    #----------------------------------------
    &AddMsg("WARN", [], "Warning");
 
    #----------------------------------------
    &AddMsg("ERROR", [], "ERROR");

    #----------------------------------------
    &AddMsg("FATAL", [], "FATAL");

    &AddMsg("BUTTON_TEXT_ABORT", [], "Abort");
    &AddMsg("BUTTON_TEXT_YES", [], "Yes");
    &AddMsg("BUTTON_TEXT_RETURN", [], "RETURN");
    &AddMsg("BUTTON_TEXT_ENTER", [], "ENTER");


################################################################
#:::IOPTK_*: IOPTK* class messages

##################################################
#::::IOPTK_E_*: Error messages

    &AddMsg("IOPTK_E_DUP_WIDGET", [ "<NAME>", "<PARENT>" ],
"Duplicate widget name exists for %s. The parent is: %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_PARENT", [ "<PARENT>","<NAME>"],
"Unknown parent %s found. Problem found in widget %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_SUBTYPE", [ "<SUBTYPE>","<CLASS>"],
"Unknown subtype %s found. Problem found for widget class %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_UNKNOWN_WIDGET", [ "<NAME>" ],
"Unknown widget %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_NOT_PARENT", [ "<PARENT>", "<NAME>" ],
"Proposed parent %s doesn't manage children widgets. Problem was found for widget %s");

    #----------------------------------------
    &AddMsg("IOPTK_E_CONVERSION_ERROR", [ "<ROUTINE>", "<ERROR>" ],
"The following conversion error occurred in user interface display (%s): 
%s");

################################################################
#:::MC_*:    MsgCat class messages

################################################################
#:::MC_*:    MsgCat Error messages

    &AddMsg("MC_E_CONVERSION_ERROR", [ "<SOURCE>", "<DEST>", "<ERROR>" ],
"Error occurred converting string from %s to %s.
%s");

    # NOTE: Should be ASCII safe
    &AddMsg("MC_E_CONVERSION_MARKER", [ ],
"(conversion failed)");

    &AddMsg("MC_E_TRUNCATION_MARKER", [ ],
"... (error message truncated)");

    &AddMsg("MC_E_I18N_ICONVEX_OK", [ ],
"Codepage conversion error: Success");

    &AddMsg("MC_E_I18N_ICONVEX_INPUT_INCOMPLETE", [ ],
"Codepage conversion error: The input buffer ends with an incomplete multibyte character");

    &AddMsg("MC_E_I18N_ICONVEX_OUTPUT_FULL", [ ],
"Codepage conversion error: Not enough room for output in the output buffer");

    &AddMsg("MC_E_I18N_ICONVEX_INPUT_CONV_ERROR", ["<STRING>","<ERRORS>"],
"Codepage conversion error: No such character(s) in input character set.
The string is \'%s\'
The following characters are invalid:
%s
");

    &AddMsg("MC_E_I18N_ICONVEX_OUTPUT_CONV_ERROR", ["<STRING>","<ERRORS>"],
"Codepage conversion error: No valid character in output character set.
The string is \'%s\'
The following characters are invalid:
%s
");

    &AddMsg("MC_E_I18N_ICONVEX_ERROR", [ ],
"Codepage conversion error: Other errors");

    &AddMsg("MC_E_I18N_ICONVEX_UNKNOWN_ERROR", [ ],
"Codepage conversion error: Unknown Error");

    &AddMsg("MC_E_NON_ASCII_I18N_DISABLED_PRE_CC7", ["<STRING>","<ERRORS>"],
"Non-ASCII characters found but code page conversions are not enabled. 
This release does not support code page conversions to handle non-ASCII 
characters. Contact your ClearCase administrator. 

The string is \'%s\'
The following characters are not ASCII characters:
%s
");

    &AddMsg("MC_E_NON_ASCII_I18N_DISABLED_CC7", ["<STRING>","<ERRORS>"],
"Non-ASCII characters found but code page conversions are not enabled. 
The Clearcase administrator should enable code page conversions
by setting CQCC_I18N_ENABLE configuration parameter. 

The string is \'%s\'
The following characters are not ASCII characters:
%s
");

#################################################################
#:::PM_*:    Parm class messages

##################################################
#::::PM_E:  Error messages

    &AddMsg("PM_E_PARM_RANGE",
             [ "<PARM>", "<VALUE>", "<MINIMUM>", "<MAXIMUM>" ],
"A problem has been detected with the following parameter-value pair: 
Parameter: %s Value: %s 
The value is outside of acceptable range
(%s to %s)");

    #----------------------------------------
    &AddMsg("PM_E_PARM_LIST", [ "<PARM>", "<VALUE>", "<LIST>" ],
"A problem has been detected with the following parameter-value pair: 
Parameter: %s Value: %s
The parameter was not found on the accepted list 
%s");

    #----------------------------------------
    &AddMsg("PM_E_TWO_PARMS", [ "<PARM>" ],
"Two parameters are using the same name or being defined twice: 
%s");

    #----------------------------------------
    &AddMsg("PM_E_UNKNOWN_PARM", [ "<PARM>"],
"Unknown parameter %s");

    #----------------------------------------
    &AddMsg("PM_E_CONVERSION_ERROR", [ "<PARM>","<VALUE>"],
"Conversion error detected for parameter: %s. Parameter has value: %s");

#################################################################
#:::TBASE_*: TriggerBase class messages

##################################################
#::::TBASE_E:  Error messages

    &AddMsg("TBASE_E_BAD_RESULT", [ "<RESULT>", "<OPERATION>" ],
"Unexpected result (%s) returned from %s operation");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_ARG", [ "<ARGUMENT>" ],
"Trigger Menu: unknown command line argument %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_MENU", [ "<MENU>"],
"Trigger MenuDisplay: Unknown menu %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_METHOD", [ "<METHOD>" ],
"Trigger Menu: unknown callback method %s");

    #----------------------------------------
    &AddMsg("TBASE_E_UNKNOWN_SYSTEM", [ "<SYSTEM>" ],
"Unable to connect to %s system");

    #----------------------------------------
    &AddMsg("TBASE_E_NO_OPERATION", [],
"No operation specified for trigger");

    #----------------------------------------
    &AddMsg("TBASE_E_LOAD_CACHE_SERIES", ["<CACHE_FILE>"],
"LoadCache: Unable to find pre-checkin series cache file:
    %s
Continuing with operation may cause further data loss.
Please report this problem to your ClearCase administrator");

    #----------------------------------------
    &AddMsg("TBASE_E_SAVE_CACHE_SERIES", [],
"SaveCache: Unable to cache required information from pre-checkin trigger for 
post-checkin trigger because both ClearCase process ID and Series ID are unset. 
Please report this problem to your ClearCase administrator.");

##################################################
#::::TBASE_I:  Info  messages

    &AddMsg("TBASE_I_HELP", [], 
"This script implements the Base ClearCase-ClearQuest integration. 

The script is usually invoked as a ClearCase trigger with these
optional parameters.  Because the script usually relies on a number of
environment variables set up by ClearCase, you typically do not run it
from the command line. You may need to run it from the command line to
perform special administrative operations.

These two parameters are normally used by ClearCase Trigger calls.

    -required  This parameter requires the user to specify at least 
               one ClearQuest change request to be associated with a 
               checkout or checkin operation. This parameter is 
               ignored for uncheckout operations.

    -entitydef <name>
               Use this parameter to specify a ClearQuest record type
               as the initial default record type that the user works 
               with. The initial default record type is 'defect'. 
               This parameter is ignored for uncheckout operations; 
               the record type stored with existing associations is 
               used instead.

These four parameters are useful to administrators calling the
trigger directly from the command line.

    -help      Produce this message and exit.

    -usage     Describes the command line arguments to the script.

    -test      Tests connections with ClearQuest and displays the
               output of the STANDARD query for the default database
               and entity (record type). 

               If ClearQuest is installed locally, the integration
               tries to use CQPERL and the CQPerl API to the 
               database, relying on connections established by 
               the ClearQuest Maintenance Tool or UNIX environment
               variables. 

               If ClearQuest is not installed locally or if the 
               CQCC_CQWEB_ONLY parameter is enabled, the integration 
               uses the CQWeb interface. The CQWeb interface uses 
               environment variables CQCC_SERVER and CQCC_SERVERROOT 
               (or CQCC_URL) to attempt to set up a session with a 
               remote Windows ClearQuest webserver by sending a no-op 
               instruction to verify that the ASP page on the server 
               produces an expected response. This test also verifies
               that your ClearQuest username and password are working.
               In test mode, the script does not interact with 
               ClearCase. If the script fails in test mode it is not
               due to a ClearCase problem.

    -vob       The -vob option is recommended for end-users as a 
               convenience. It tells the trigger launch script to get 
               the main command line arguments from the checkout trigger 
               in the current vob. This provides the correct paths to 
               cqcc_launch, the config file, and trigger source and 
               avoids user concerns about where the config file resides, 
               etc.  You must be inside a vob that has active triggers 
               inside it to be able to use this option however.

The following advanced parameters are used by trigger developers or
testers.

    -p parmName,parmValue
                This option specifies a command line parameter
                to change to the given value. 

    -op operation arg,arg,...
                This option specifies an operation to run, such as 
                classtest, and the arguments that the operation 
                takes. 

                The edit operation (-op edit) is useful for making 
                changes in associations after checkins. It prompts
                for the version pathname and vob information it needs
                then redisplay the main association menu. 

                The batch operation (-op batch) is useful for manually
                forcing the association batch file to be processed when
                the CQCC_ASSOC_BATCH_ENABLE option is used. By default,
                it assumes the same CQCC_ASSOC_BATCHFILE setting as the
                config file but the filename can be provided as an argument.

    -central <path> The -central option is not recommended for end-users. 
               It identifies where the integration and config.pl file 
               reside when centralized triggers are in use and is intended 
               for trigger execution commands only. Use the -vob option for
               end user access instead.

    -path <configPath> The -path option is used internally between the 
               trigger launch script and the main trigger code 
               informational purposes only. 

    -postop    The -postop option identifies if the trigger is being 
               executed is a pre-op trigger (default) or a post-op 
               trigger (if switch is used). 

    -silent    The -silent option signals that user interaction should 
               be skipped for checkins in checkout-only situations. 

You can modify the behavior of this script by editing the site config
file, CQCC/config.pl. The primary reason for doing this would be to
adapt the script to run with a ClearQuest database schema other than
the SAMPL schema supplied with ClearQuest. In particular, all field
names used by this script to generate queries must be present (with
identical spelling) in the database schema. See your ClearQuest
administrator for more information on the schema you are using.  
");

    #----------------------------------------
    &AddMsg("TBASE_I_USAGE", 
             [ "<COMMAND>", "<COMMAND>", "<COMMAND>" ], 
"Usage: 
%s [-required] [-entitydef <name>] [-vob]
   -required - Set flag if at least one change request must be 
          specified. Ignored for uncheckout.
   -entitydef - Defaults to 'defect'. 
          Set if other record type is to be used.
   -vob - Uses central path and config file name from triggers in 
          current vob for convenience.
   -p parm,value - Sets value of command line parameter.
   -op operator arglist - Specifies operation to run. Normally
          operator is determined from the CLEARCASE_OP_KIND 
          environment variable.

OR: %s -test - Tests settings of required environment variables and 
          communication with the CQ server.

OR: %s -help - Prints help message and exits.
          Describes additional advanced parameters used internally. 
");

#################################################################
#:::TCQCC_*, Action*, Dialog*, Menu: TriggerCQCC class messages

##################################################
#::::TriggerCQCC Parameter descriptions

    &AddMsg("CQCC_MULTIPLE_ASSOCS", [],
"This switch selects whether the user can make only one association
('FALSE') or multiple associations ('TRUE', default) per operation.");

    &AddMsg("CQCC_AUTO_ASSOCIATE", [],
"Use this option to specify one or more change requests that you want
to associate with files on checkout and checkin operations. See the
README file or online help for details.");

    &AddMsg("CQCC_AUTO_ASSOCIATE_ENABLE", [],
"Use this option to specify whether users may use the 
CQCC_AUTO_ASSOCIATE option.  To prohibit use of the CQCC_AUTO_ASSOCIATE
option, set CQCC_AUTO_ASSOCIATE_ENABLE to \"FALSE\".  To allow use of
CQCC_AUTO_ASSOCIATE, set CQCC_AUTO_ASSOCIATE_ENABLE to \"TRUE\".");

    &AddMsg("CQCC_COMMENT_PATTERN", [],
"Use this option to specify a comment pattern that will allow 
users to make associations by entering a checkin or checkout 
comment that matches the pattern.  In this way, users can avoid 
starting the integration's user interface for associating files 
with change requests.  To enable this option, specify a pattern 
in the form of a Perl expression. For example, a pattern set to
\"BUGS:\\\\[(\\\\S+)\\\\]\" would match \"This fixes BUGS:[SAMPL1,2,3]\"
This example uses the double backslash to escape each backslash.
The change requests that users enter on checkin commands 
override the change requests that they specified on checkout 
commands.  If the CQCC_AUTO_ASSOCIATE option is enabled, the 
integration uses that instead of the CQCC_COMMENT_PATTERN 
option when making associations.");

    &AddMsg("CQCC_CQWEB_ONLY", [],
"This switch is used to force using the CQWeb interface even when
ClearQuest and CQPerl are found on the client machine.");

    &AddMsg("CQCC_POSTCHECKIN_VERIFY", [], 
"After checkin, confirm that the correct Object IDs are being saved 
in ClearQuest.");

##################################################
#::::TCQCC_E:  Error messages

    &AddMsg("TCQCC_E_ASSOC_NOT_SPECIFIED", [],
"You must specify a ClearQuest change request to associate with this 
operation.");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_INPUT_ERROR", ["<LINENUM>","<LINE>"], 
"Unable to parse batch file input line %s: 
%s");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_INPUT_FAILED", ["<FILENAME>"], 
"Unable to open batch input file %s");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_OUTPUT_FAILED", ["<FILENAME>"], 
"Unable to open output file %s
Making immediate changes to ClearCase and ClearQuest");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_OP_FAILED", ["<FILENAME>"], 
"Unable to complete processing ClearQuest transaction batch file
   %s
because of errors reporting posting transactions. Resolve problems and 
perform another ClearCase checkout, uncheckout or checkin operation to
retry the batch or contact your local administrator for assistance.");

    #----------------------------------------
    &AddMsg("TCQCC_E_BATCH_UNKNOWN_OP", ["<OP>"], 
"Batch operation Action parameter unknown (%s)
It should be one of the following: do, undo, or noop");

    #----------------------------------------
    &AddMsg("TCQCC_E_BUGLIST_INPUT", ["<DATA>", "<DBNAME>", "<RECTYPE>"], 
"There was an error in the input list: 
    %s
You can enter either complete IDs with a leading database name or just
numbers or a mix of the two modes. If you enter the database name, then it
must match the current database name: (%s). Record type name: (%s) must also match. 
Please re-enter the information.");

    #----------------------------------------
    &AddMsg("TCQCC_E_EXISTING_BUGS_LOCK_DB", [], 
"You cannot change the database when there are already existing 
associations.");

    #----------------------------------------
    &AddMsg("TCQCC_E_GDTRIGGER_INCOMPATIBLE", [], 
"The GDTrigger trigger class, originally provided as a hotfix, is 
superceded by this version of the main trigger and is incompatible.");

    #----------------------------------------
    &AddMsg("TCQCC_E_NO_ASSOCS", [], 
"The REVIEW option is used to view or delete from an existing list of
proposed associations. There are no existing or proposed associations
to edit. Use the QUERY option to select from a ClearQuest query, or 
use the TYPEIN option to enter the change request IDs directly.

If you need to create a new change request for the checkin operation, 
you must start ClearQuest manually, create the new entry, then run the
QUERY or TYPEIN options again.
");

    #----------------------------------------
    &AddMsg("TCQCC_E_NO_MULTI_ASSOCS", [], 
"POLICY: Multiple associations are not permitted - please select only
one association for each checkin or checkout.");

    #----------------------------------------
    &AddMsg("TCQCC_E_QUERY_EMPTY", ["<USER>"],
"Query returned no open change requests for user '%s'");

    #----------------------------------------
    &AddMsg("TCQCC_E_WEB_NOT_SUPPORTED", [],
"Base CC/CQ Integration is not currently supported under ClearCase Web Servers");

    #----------------------------------------
    &AddMsg("TCQCC_E_SELECTION", [],
"Please make a select from the list or hit 'Cancel' to exit");

    #----------------------------------------
    &AddMsg("TCQCC_E_ID_MUST_BE_FIRST", ["<QUERY_NAME>"], 
"The integration requires the first column in a query to be the ID field.
Please modify this query (%s) or select another query if possible");

##################################################
#::::TCQCC_I:  Info messages

    &AddMsg("TCQCC_I_BATCH_CONFIRM", [],
      "\nClearQuest transactions have successfully been posted to the database.");

    #----------------------------------------
    &AddMsg("TCQCC_I_GETBUGS_HELP", [], 

"Enter a list of ClearQuest change requests to associate with this
ClearCase operation.  You may enter full ClearQuest change request
IDs (SAMPL00000023 or SAMPL34) or just numbers (000023 or 34)
or any combination, separated by spaces or commas. When specified, 
the database must match the current database you are logged into 
or an error will occur. 

If the prompt message for the list begins with 'Required:', you must
provide at least one change request ID for the ClearCase operation to
succeed. If associations are optional and you don't want to make any,
Click Abort/Cancel or hit RETURN.
");

##################################################
#::::TCQCC_P:  Prompt messages

    &AddMsg("TCQCC_P_QUERY_RESULTS", ["<USER>"],
"Open change requests assigned to user %s");

    #----------------------------------------
    &AddMsg("TCQCC_P_QUERY_ASSOCLIST", ["<KEY>"],
"Associated Records - select items or hit %s");

    #----------------------------------------
    &AddMsg("TCQCC_P_VOBPN", [], "Please enter VOB tag:");

    #----------------------------------------
    &AddMsg("TCQCC_P_XPN", [], "Please enter Extended Pathname:");

    #----------------------------------------
    &AddMsg("TCQCC_P_ENTER_BUGS_NOWARN_OPT",
            ["<OP>", "<FILE>"],
"(Optional) Enter ClearQuest change request IDs to associate with the action: %s for file:
%s, separated by spaces or commas. 

If no associations are to be made, hit RETURN.");

    #----------------------------------------
    &AddMsg("TCQCC_P_ENTER_BUGS_NOWARN_REQD",
            ["<OP>", "<FILE>"],
"(Required) Enter ClearQuest change request IDs to associate with the action: %s for file:
%s, separated by spaces or commas. 

If no associations are to be made, hit RETURN.");

##################################################
#::::Action_*:  TriggerCQCC Action menu items

    &AddMsg("Action_Cancel", [], "CANCEL current operation only");

    #----------------------------------------
    &AddMsg("Action_Cancel_ApplyToAll", [],
"CANCEL remaining operations in batch");

    #----------------------------------------
    &AddMsg("Action_Commit", [], 
"OK - Apply current associations to current file only");

    #----------------------------------------
    &AddMsg("Action_Commit_ApplyToAll", [],
"OK - Apply current associations to all files in batch");

    #----------------------------------------
    &AddMsg("Action_Commit_ApplyToAll_UseCheckouts", [],
"OK - Apply original checkout associations to all files in batch");

    #----------------------------------------
    &AddMsg("Action_Return", [], "Return to main menu");

    #----------------------------------------
    &AddMsg("Action_Help", [ "<TOPIC>" ],
"HELP - Display help for this menu");

    #----------------------------------------
    &AddMsg("Action_Noop", [], "------");

##################################################
#::::Dialog_*:  TriggerCQCC Dialog menu items

    &AddMsg("Dialog_Cancel", [], "CANCEL");

    #----------------------------------------
    &AddMsg("Dialog_Cancel_Menu", [], 
"CANCEL changes during batch operation");

    #----------------------------------------
    &AddMsg("Dialog_Cancel_Help", [],
"Because you are in the middle of a batch of versions being 
processed at once you can specify how to handle the rest of the 
versions automatically.
");

    #----------------------------------------
    &AddMsg("Dialog_Commit", [], "OK - Commit associations");

    #----------------------------------------
    &AddMsg("Dialog_Commit_Help", [], 
"Because you are in the middle of a batch of versions being 
processed at once you can specify how to handle the rest of the 
versions automatically.
");

    #----------------------------------------
    &AddMsg("Dialog_Commit_Menu", [], 
"Commit associations during batch operation");

    #----------------------------------------
    &AddMsg("Dialog_EditDesiredAssocs", [ "<ASSOCLIST>" ],
"REVIEW associations: ( %s ) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectByTypein", [],
"TYPEIN - Enter associations from keyboard ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectByQuery", [], 
"QUERY - Select from ClearQuest query ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectDatabase", [ "<DATABASE>" ],
"DATABASE (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectEntity", [ "<ENTITY>" ], 
"RECORD TYPE (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_DisplayXPN", [ "<PATHNAME>" ],
"PATHNAME (%s) ...");

    #----------------------------------------
    &AddMsg("Dialog_SelectQueryName", [ "<QUERYNAME>" ],
"QUERYNAME (%s) ...");

    #----------------------------------------
    &AddMsg("Action_ClearCQLogin", [ ],
"RELOGIN CLEARQUEST");

##################################################
#::::GUI_*:  TriggerCQCC GUI tags

    &AddMsg("GUI_Title_CQCC_Integration", [], 
        "ClearCase-ClearQuest integration");

    #----------------------------------------
    # Menu 1 - Associated Records and main operations

    &AddMsg("GUI_Title_AssocRecords", [], "Associated Records:");
    &AddMsg("GUI_Commit", [], "OK");
    &AddMsg("GUI_Cancel", [], "Cancel");
    &AddMsg("GUI_ApplyToAll", [], "Apply to all");
    &AddMsg("GUI_Disassociate", [], "Disassociate");
    &AddMsg("GUI_ClearCQLogin", [], "Relogin ClearQuest");
    &AddMsg("GUI_Help", [], "Help");

    #----------------------------------------
    # Mid bar buttons

    &AddMsg("GUI_Database", [], "Database");
    &AddMsg("GUI_RecordType", [], "Record Type");

    #----------------------------------------
    # Menu 2 - Query Results and related operations

    &AddMsg("GUI_Title_Query", [], "Query:");
    &AddMsg("GUI_Title_Results", [], "Results");
    &AddMsg("GUI_Browse", [], "Browse...");
    &AddMsg("GUI_Associate", [], "Associate");
    &AddMsg("GUI_Refresh", [], "Refresh");
    &AddMsg("GUI_Typein", [], "Type in IDs");

    #----------------------------------------
    # Query Browser Dialog

    &AddMsg("GUI_Title_SelectQuery", [], "Select Query");

    #----------------------------------------
    # IOPerlTK Dialog Box messages

    &AddMsg("GUI_ListSelect", [], "Select from list");
    &AddMsg("GUI_Message", [], "Message");
    &AddMsg("GUI_Prompt", [], "Prompt");

    #----------------------------------------
    # Help Topics

    my $OverrideMessage = "
==========================================================

To specify one or more change requests to associate with a
batch of files without displaying the user interface: 

1. Set the environment variable CQCC_AUTO_ASSOCIATE to the
associations you want to make before starting cleartool or ClearCase
Explorer.

If enabled at your site, use this option to specify one or more change
requests that you want to associate with files on checkout and checkin
operations.  The integration uses the change requests that you specify
rather than prompting you through the user interface.  The ApplyToAll
mechanism works only for files being versioned in a single checkin or
checkout command.  This option lets you handle large batches of files
in multiple checkin and checkout commands.

Use the same conventions used in the Type In option in the user
interface to specify change requests.  For example, \"SAMPL1,2,3\"
identifies change request IDs 1, 2, and 3 in the SAMPL user database.

The values you specify remain in effect until you unset the option or
set it to \"\".  On checkin operations, the integration uses the values
you specify with this option to override associations you made on
checkouts.  Specify \"-\" to set the option to select no change
requests.  If errors occur, the integration displays them and starts
the user interface for associating change requests.";

    &AddMsg("GUI_HelpMain", [],
"This dialog box allows you to find and associate one or more records
in a ClearQuest database and ClearCase elements in your application.

The upper half of the dialog box displays the records you plan to
associate the current version with. Click OK or Apply to All to 
commit these associations to the database. If your application 
supports multiple associations, click Apply to All only to associate
or disassociate the record(s) with multiple versions in your
application. To undo any association changes that you make in this
dialog box, click Cancel.

The lower half of this dialog box allows you to browse through
queries to find the record(s) you want, and add the records to
the Associated Records list.

 ==========================================================

To associate a record and a version:

1. Click Browse to find the record(s) you need in the existing
queries and their results. In the Select Query dialog box, select
a query, click OK, and wait for the new results to be displayed. 

Note: The Browse button may be disabled depending on local site
policies.

2. When the selected query displays in the Query window, scroll
through the results grid to find and select the record you need. If
your application supports multiple associations, use Ctrl+click and 
Shift+click to select multiple records.

Note: Click and drag the right edge of the column heading to resize
the column. Click the column heading to change the sort order of the
records by the values in that column (either ascending or descending).

3. To add the selected record(s) to the Associated Records list,
click Associate. (These records are not committed to the database
until you click OK or Apply to All.) 

4. If you don't see the record(s) you are looking for, click Type In
IDs and directly enter the IDs of the records. When you commit the
Type In IDs operation, all entered IDs are subject to local
restrictions set by your site administrator.

5. To create a new record or define a new query, start ClearQuest
normally, save the information, and, in the integration window, click
Refresh to display the latest query results and lists.

6. In the Associate Record dialog, click OK to commit the associations
and return to your application.

 ==========================================================

To disassociate a record and a version:

1. Select the record(s) in the Associated Records list.

2. Click Disassociate. The record is removed from the list.

3. Click OK or Apply to All to commit your changes and return to your
application.

 ==========================================================

To change the current database: 

Note: If there are existing associations for this checkout, you cannot
change databases.

1. Click Database. A list of allowed databases appears. 

2. Select the database you want to make associations with. 

You may be prompted for login information if the information differs
from that of the database you were logged in to. If the record type
that you were using is not supported in the new database, an alternate
record type is selected automatically. If the current query is not
supported in the new database, the STANDARD query is set.

 ==========================================================

To change the current record type:

1. Click Record Type. A list of allowed record types appears. 

2. Select the record type you want to make associations with. 

" . $OverrideMessage);

##################################################
#::::MENU_*:  TriggerCQCC Menu help

    &AddMsg("MENU_ASSOCIATION", [],
"This menu allows you to make associations between a ClearCase 
version and one or more ClearQuest change requests. It provides 
the following options:

* OK - Commit associations: Make the requested associations and exit.

* CANCEL: Exit without making any changes and terminate the ClearCase
operation that brought you here. When you cancel a checkout operation,
the file(s) will automatically be un-checked out which may cause some
Clearcase warnings to appear which you can ignore. 

* HELP: Print this message. 

* -------: (menu divider)

* QUERY - Select from ClearQuest query: This option displays the
contents of a query defined by your local administrator to show change
requests that are appropriate for you to select from. Depending on the
local policy, you may select one or multiple items.

* TYPEIN - Enter associations from keyboard: This option allows you to
directly enter one or more change request IDs, separated by spaces or
commas.

* REVIEW associations: This option shows currently selected
associations and allows you to delete one or more items from the
list. Within the menu itself, it shows the currently associated
change request IDs. When selected, it presents a detailed list
of the same change requests. You can then select items to delete, or
return without making any deletions (hit Cancel/RETURN).

* -------: (menu divider)

* DATABASE: Shows the current database name and allows you to 
change to a different database.

* RECORD TYPE: Shows the current record type (defect, change request,
and so on) that you are working with and allows you to change to
different record type if the current database supports more than one.

* PATHNAME: Shows the item that you are checking in or checking out.
Selecting this item provides more information if it is available.

* QUERYNAME: Shows the current query used in the QUERY option above.
If this option appears, you will be presented with a list of alternate
queries either defined by the configuration file (LOCAL) or in the
ClearQuest database itself. Which queries appear is determined by 
your site administrator. 

" . $OverrideMessage);

    #----------------------------------------
    &AddMsg("TITLE_ASSOCIATION_MENU", ["<KEY>"],
"ClearQuest Association Menu - select option, hit %s");

################################################################
#:::TCM_*:    Trigger Cache Mgr messages
#::::TCM_E:  Error messages

    &AddMsg("TCM_E_CACHE_ACCESS", [],
"Base CC/CQ Integration Cache manager must have access to central 
cache directory");

    &AddMsg("TCM_E_NONEXIST_DIR", ["<PATH>"],
"Base CC/CQ Integration Cache manager can't process non-existent directory
(%s)");

    &AddMsg("TCM_E_FAILED_POST", ["<PATH>"],
"Failed to successfully post batch, please investigate
%s");

    &AddMsg("TCM_E_CQLOGIN_UNSUPPORTED", [],
"CM_CQLOGIN feature not supported before Clearcase 7.0.1, use caching\n");

    &AddMsg("TCM_E_CQLOGIN_FAILED", [],
"ClearQuest password decryption failed");

#::::TCM_T:  Tags for other messages

    &AddMsg("TCM_T_LOG_HEADER", ["<TIME>","<CACHE_PATH>"],
"Base CC/CQ Integration Cache Manager: Running (%s)
    Cache Root Dir: %s");

    &AddMsg("TCM_T_RUN_TOTALS", [], "Run totals");
    &AddMsg("TCM_T_VALUE", [], "Value");
    &AddMsg("TCM_T_COUNT", [], "Count");

    &AddMsg("TCM_T_PATTERN_MATCH", ["<PATTERN>","<ATTRIBS>","<HOURS>"], 
"Pathname matches pattern %s - %s (Age = %s hours)");

    &AddMsg("TCM_T_UNKNOWN_COUNT", ["<NAME>", "<VALUE>"], 
"Unknown Count value (%s=%s)");

    &AddMsg("TCM_T_INTERESTING_FILE", [], 
"File may be of interest for diagnostic purposes");

    &AddMsg("TCM_T_UNKNOWN_FILE_PATTERN", ["<NAME>", "<VALUE>"], 
"Unknown file pattern attributes (%s=%s)");

    &AddMsg("TCM_T_FILE_UNEXPECTED", [],
"WARNING: File doesn't fit expected file name patterns
        Administrator should investigate and remove manually");

    &AddMsg("TCM_T_RULE_OVER_AGE", ["<RULENAME>","<AGE>","<AGELIMIT>"],
"Rule %s (age %s hours > %s hours)");

    &AddMsg("TCM_T_WOULD_DELETE_FILE", [],
"Would delete file ");

    &AddMsg("TCM_T_CANT_DELETE_FILE", [],
"Error: Unable to delete file");

    &AddMsg("TCM_T_DELETED_FILE", ["<REASON>"],
"Deleted file (%s)");

    &AddMsg("TCM_T_WOULD_POST_BATCH", ["<PATHNAME>"],
"Would post batch file %s");

    &AddMsg("TCM_T_POSTING_BATCH", ["<COMMAND>"],
"Posting Batch: command
%s");

    &AddMsg("TCM_T_WOULD_DELETE_DIR", ["<AGE>"],
"Would delete directory because contents all over %s hours old");

    &AddMsg("TCM_T_CANT_DELETE_DIR", [],
"Error: Unable to delete directory, files remain");

    &AddMsg("TCM_T_CANT_DELETE_DIR2", ["<PATH>"],
"Error: Unable to delete directory %s");

    &AddMsg("TCM_T_DELETED_DIR", ["<REASON>"],
"Deleted directory (Rule %s)");

#:::TM_*:    Timer class messages

}

######################################################################
#::function AddMsg
# 
# This internal convenience function is used to add messages during 
# initialization
#
######################################################################

sub AddMsg {
    my ($ckey, $args, $msg) = @_;
    $arguments{$ckey} = $args ? $args : [];
    $catalog{$ckey} = $msg;
}

######################################################################
#::method new

=over 6

=item C<new CQCC::MsgCat_English()>

This constructor calls the super classes new function then its
own Initialize() method in order to load the message catalog. 

=back

=cut

######################################################################

sub new { 
   my $proto = shift;
   my $class = ref($proto) || $proto;  # Object or class name
   my $self;
   
   # CCperl doesn't support SUPER so use direct reference to parent
   $self = new CQCC::MsgCat();

   $self->{CLASSNAME} = "CQCC::MsgCat_English";
   bless($self, $class);

   # In subclasses, make sure to follow this pattern:
   #    Set local working catalog and arglists hashlists to current
   #    values, initialize adds messages, then restore the catalogs. 

   #%arguments = \$self->{ARGLISTS};
   #%catalog = \$self->{CATALOG};

   %arguments = ();
   %catalog = ();

   $self->Initialize();

   $self->{ARGLISTS} = \%arguments;
   $self->{CATALOG} = \%catalog;

   return $self;
}

#################################################################
#::method YesNo

=over 6

=item C<YesNo(answer)>

This method compares a given answer to the local values for "yes"
and "no" and returns 0 for neither, 1 for "yes", and 2 for "no".
Local message catalogs can override this method to provide more flexible
matches handling local conventions like case and partial answers,
i.e. "Y" for "yes".

This method tries to find local values for "yes" and "no" by checking
its contents for two tags, IO_P_YES and IO_P_NO. If either is not found
it returns 0 for neither. 

=back

=cut

######################################################################

sub YesNo {
    my ($self, $answer) = @_;
    my $result = 0;
    my $yes = $self->Message([ "IO_P_YES" ]);
    my $no = $self->Message([ "IO_P_NO" ]);
    if (defined $answer && length($answer) > 0 && 
        defined $yes and defined $no) {
        #Case insensitive, partial answer match of answer
        if (uc($answer) eq substr(uc($yes),0,length($answer))) {
            $result = 1;
        } elsif (uc($answer) eq uc($no)) {
            $result = 2;
        }
    }
    return $result;
}

######################################################################
#::Tail
#################################################################

1;
